#!/usr/bin/env python3
"""Example script entry (skeleton)."""

from __future__ import annotations

from furlan_g2p.services.pipeline import PipelineService


def main() -> None:
    """Run the example pipeline (unimplemented)."""
    _ = PipelineService()
    raise NotImplementedError("Example script is not implemented yet.")


if __name__ == "__main__":  # pragma: no cover
    main()
